@@ -363,7 +363,7 @@ structElemToPyPack _ m accessor (ExprField name typ expr) =
                                                            , e
                                                            ])]
        CompositeType _ _ -> Right $ [(name',
-                                      mkCall (mkDot e (mkName "pack")) noArgs)]
+                                      mkCall (mkDot e "pack") noArgs)]
 
 -- As near as I can tell here the padding param is unused.
 structElemToPyPack _ m accessor (ValueParam typ mask _ list) =
@@ -583,7 +583,11 @@ processXDecl ext (XError name opcode membs) = do
                        ]
 processXDecl ext (XRequest name opcode membs reply) = do
   m <- get
-  let (args, packStmts) = mkPackStmts ext name m id "x%c2x" membs
+  let
+      -- xtest doesn't seem to use the same packing strategy as everyone else,
+      -- but there is no clear indication in the XML as to why that is. yay.
+      prefix = if ext == "xtest" then "xx2x" else "x%c2x"
+      (args, packStmts) = mkPackStmts ext name m id prefix membs
       cookieName = (name ++ "Cookie")
       replyDecl = concat $ maybeToList $ do
         reply' <- reply
